### Challenge

Prepare, optimize and reproduce MLPerf inference v2.1 benchmarks across diverse implementations, software and hardware
using the [MLCommons CK framework](https://github.com/mlcommons/ck).

### Organizers

* [MLCommons taskforce on automation and reproducibility](https://cKnowledge.org/mlcommons-taskforce)
* [cTuning foundation](https://cTuning.org)
* [OctoML](https://octoml.ai)

### Status

This challenge has been successfully completed.

### Results

Results are available [here](https://access.cknowledge.org/playground/?action=experiments&tags=mlperf-inference,v2.1).
